==> mobile-orm-1.0.0-sources.jar: com/oogbox/support/orm/core/helper/MobileORMConfig.java <==
package com.oogbox.support.orm.core.helper;

import android.content.Context;

import com.oogbox.support.orm.BaseModel;
import com.oogbox.support.orm.core.annotation.DataModel;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.LinkedHashMap;

public abstract class MobileORMConfig {

    private Context context;
    private LinkedHashMap<String, Class<? extends BaseModel>> modelClasses = new LinkedHashMap<>();

    public MobileORMConfig(Context context) {
        this.context = context;
    }

    public Context getContext() {
        return context;
    }

    public final HashMap<String, BaseModel> getModels() throws NoSuchMethodException,
            IllegalAccessException, InvocationTargetException, InstantiationException {
        HashMap<String, BaseModel> models = new HashMap<>();
        for (String model : modelClasses.keySet()) {
            BaseModel modelObj = getModel(model);
            if (modelObj != null) {
                models.put(model, modelObj);
            }
        }
        return models;
    }

    public final BaseModel getModel(String modelName) throws NoSuchMethodException, IllegalAccessException,
            InvocationTargetException, InstantiationException {
        if (modelClasses.containsKey(modelName)) {
            Constructor constructor = modelClasses.get(modelName).getConstructor(Context.class);
            return (BaseModel) constructor.newInstance(getContext());
        }
        return null;
    }

    @SafeVarargs
    protected final void register(Class<? extends BaseModel>... models) {
        for (Class<? extends BaseModel> cls : models) {
            DataModel model = cls.getAnnotation(DataModel.class);
            if (model != null) {
                modelClasses.put(model.value(), cls);
            }
        }
    }

    public String getDatabaseName() {
        return null;
    }

    public abstract String authority();
}

==> mobile-orm-1.1.2-sources.jar: com/oogbox/support/orm/core/helper/MobileORMConfig.java <==
package com.oogbox.support.orm.core.helper;

import android.content.Context;

import com.oogbox.support.orm.BaseModel;
import com.oogbox.support.orm.core.factory.BaseModelCursorFactory;
import com.oogbox.support.orm.core.annotation.DataModel;
import com.oogbox.support.orm.models.ORecordSequence;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.LinkedHashMap;

public abstract class MobileORMConfig {

    private Context context;
    private LinkedHashMap<String, Class<? extends BaseModel>> modelClasses = new LinkedHashMap<>();

    public MobileORMConfig(Context context) {
        this.context = context;
        register(ORecordSequence.class);
    }

    public Context getContext() {
        return context;
    }

    public final HashMap<String, BaseModel> getModels() throws NoSuchMethodException,
            IllegalAccessException, InvocationTargetException, InstantiationException {
        HashMap<String, BaseModel> models = new HashMap<>();
        for (String model : modelClasses.keySet()) {
            BaseModel modelObj = getModel(model);
            if (modelObj != null) {
                models.put(model, modelObj);
            }
        }
        return models;
    }

    public final BaseModel getModel(String modelName) throws NoSuchMethodException, IllegalAccessException,
            InvocationTargetException, InstantiationException {
        if (modelClasses.containsKey(modelName)) {
            Constructor constructor = modelClasses.get(modelName).getConstructor(Context.class);
            return (BaseModel) constructor.newInstance(getContext());
        }
        return null;
    }

    @SafeVarargs
    protected final void register(Class<? extends BaseModel>... models) {
        for (Class<? extends BaseModel> cls : models) {
            DataModel model = cls.getAnnotation(DataModel.class);
            if (model != null) {
                modelClasses.put(model.value(), cls);
            }
        }
    }

    public String getDatabaseName() {
        return null;
    }

    public int getDatabaseVersion() {
        return -1;
    }

    public BaseModelCursorFactory getCursorFactory() {
        return new BaseModelCursorFactory();
    }

    public abstract String authority();
}
